@@ -1,44 +1,39 @@
 package Net::DNS::RR::NAPTR;
 #
-# $Id: NAPTR.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+# $Id: NAPTR.pm 102 2004-08-12 05:16:06Z ctriv $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS;
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.100 $)[1];
+$VERSION = (qw$LastChangedRevision: 102 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
-		my ($order) = unpack("\@$offset n", $$data);
-		$offset += &Net::DNS::INT16SZ;
-		my ($preference) = unpack("\@$offset n", $$data);
-		$offset += &Net::DNS::INT16SZ;
+		($self->{"order"} ) = unpack("\@$offset n", $$data);
+		$offset += Net::DNS::INT16SZ();
+		
+		($self->{"preference"}) = unpack("\@$offset n", $$data);
+		$offset += Net::DNS::INT16SZ();
+		
 		my ($len) = unpack("\@$offset C", $$data);
 		++$offset;
-		my ($flags) = unpack("\@$offset a$len", $$data);
+		($self->{"flags"}) = unpack("\@$offset a$len", $$data);
 		$offset += $len;
+		
 		$len = unpack("\@$offset C", $$data);
 		++$offset;
-		my ($service) = unpack("\@$offset a$len", $$data);
+		($self->{"service"}) = unpack("\@$offset a$len", $$data);
 		$offset += $len;
+		
 		$len = unpack("\@$offset C", $$data);
 		++$offset;
-		my ($regexp) = unpack("\@$offset a$len", $$data);
+		($self->{"regexp"}) = unpack("\@$offset a$len", $$data);
 		$offset += $len;
-		my($replacement) = Net::DNS::Packet::dn_expand($data, $offset);
-  
-		$self->{"order"}       = $order;
-		$self->{"preference"}  = $preference;
-		$self->{"flags"}       = $flags;
-		$self->{"service"}     = $service;
-		$self->{"regexp"}      = $regexp;
-		$self->{"replacement"} = $replacement;
+		
+		($self->{"replacement"}) = Net::DNS::Packet::dn_expand($data, $offset);
 	}
   
 	return bless $self, $class;
@@ -79,7 +74,7 @@ sub rdatastr {
 		            $self->{"replacement"} . '.';
 	}
 	else {
-		$rdatastr = "; no data";
+		$rdatastr = '';
 	}
 
 	return $rdatastr;
@@ -166,7 +161,7 @@ Returns the replacement field.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
