@@ -1,13 +1,12 @@
 package Net::DNS::RR::NIMLOC;
-
-# $Id: NIMLOC.pm,v 1.2 2002/02/13 03:53:59 ctriv Exp $
-
+#
+# $Id: NIMLOC.pm 102 2004-08-12 05:16:06Z ctriv $
+#
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 
-use Net::DNS::Packet;
-
-@ISA = qw(Net::DNS::RR);
+@ISA     = qw(Net::DNS::RR);
+$VERSION = (qw$LastChangedRevision: 102 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -45,9 +44,12 @@ Returns the record's data section as binary data.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-1998 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
+
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
